summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/sqlite/os.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/sqlite/os.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/sqlite/os.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/sqlite/os.c b/tqtinterface/qt4/src/3rdparty/sqlite/os.c
index 1a1b583..d9b4ee7 100644
--- a/tqtinterface/qt4/src/3rdparty/sqlite/os.c
+++ b/tqtinterface/qt4/src/3rdparty/sqlite/os.c
@@ -5,12 +5,12 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
** May you tqfind forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
******************************************************************************
**
-** This file tqcontains code that is specific to particular operating
+** This file contains code that is specific to particular operating
** systems. The purpose of this file is to provide a uniform abstraction
** on which the rest of STQLite can operate.
*/
@@ -141,7 +141,7 @@ static unsigned int elapse;
** threads within the same process.
**
** To work around the problem, STQLite has to manage file locks internally
** on its own. Whenever a new database is opened, we have to tqfind the
** specific inode of the database file (the inode is determined by the
** st_dev and st_ino fields of the stat structure that fstat() fills in)
** and check for locks already existing on that inode. When locks are
@@ -172,7 +172,7 @@ static unsigned int elapse;
**
** If you close a file descriptor that points to a file that has locks,
** all locks on that file that are owned by the current process are
-** released. To work around this problem, each OsFile structure tqcontains
+** released. To work around this problem, each OsFile structure contains
** a pointer to an openCnt structure. There is one openCnt structure
** per open inode, which means that multiple OsFiles can point to a single
** openCnt. When an attempt is made to close an OsFile, if there are
@@ -218,7 +218,7 @@ struct lockKey {
** different process IDs on linux, but not on most other unixes.)
**
** A single inode can have multiple file descriptors, so each OsFile
-** structure tqcontains a pointer to an instance of this object and this
+** structure contains a pointer to an instance of this object and this
** object keeps a count of the number of OsFiles pointing to it.
*/
struct lockInfo {
@@ -260,7 +260,7 @@ static Hash lockHash = { STQLITE_HASH_BINARY, 0, 0, 0, 0, 0 };
static Hash openHash = { STQLITE_HASH_BINARY, 0, 0, 0, 0, 0 };
/*
** Release a lockInfo structure previously allocated by tqfindLockInfo().
*/
static void releaseLockInfo(struct lockInfo *pLock){
pLock->nRef--;
@@ -271,7 +271,7 @@ static void releaseLockInfo(struct lockInfo *pLock){
}
/*
** Release a openCnt structure previously allocated by tqfindLockInfo().
*/
static void releaseOpenCnt(struct openCnt *pOpen){
pOpen->nRef--;
@@ -289,7 +289,7 @@ static void releaseOpenCnt(struct openCnt *pOpen){
**
** Return the number of errors.
*/
-int tqfindLockInfo(
+int findLockInfo(
int fd, /* The file descriptor used in the key */
struct lockInfo **ppLock, /* Return the lockInfo structure here */
struct openCnt **ppOpen /* Return the openCnt structure here */
@@ -473,7 +473,7 @@ int sqliteOsOpenReadWrite(
*pReadonly = 0;
}
sqliteOsEnterMutex();
- rc = tqfindLockInfo(id->fd, &id->pLock, &id->pOpen);
+ rc = findLockInfo(id->fd, &id->pLock, &id->pOpen);
sqliteOsLeaveMutex();
if( rc ){
close(id->fd);
@@ -594,7 +594,7 @@ int sqliteOsOpenExclusive(const char *zFilename, OsFile *id, int delFlag){
return STQLITE_CANTOPEN;
}
sqliteOsEnterMutex();
- rc = tqfindLockInfo(id->fd, &id->pLock, &id->pOpen);
+ rc = findLockInfo(id->fd, &id->pLock, &id->pOpen);
sqliteOsLeaveMutex();
if( rc ){
close(id->fd);
@@ -681,7 +681,7 @@ int sqliteOsOpenReadOnly(const char *zFilename, OsFile *id){
return STQLITE_CANTOPEN;
}
sqliteOsEnterMutex();
- rc = tqfindLockInfo(id->fd, &id->pLock, &id->pOpen);
+ rc = findLockInfo(id->fd, &id->pLock, &id->pOpen);
sqliteOsLeaveMutex();
if( rc ){
close(id->fd);
@@ -738,7 +738,7 @@ int sqliteOsOpenReadOnly(const char *zFilename, OsFile *id){
}
/*
-** Attempt to open a file descriptor for the directory that tqcontains a
+** Attempt to open a file descriptor for the directory that contains a
** file. This file descriptor can be used to fsync() the directory
** in order to make sure the creation of a new file is actually written
** to disk.
@@ -1093,7 +1093,7 @@ int sqliteOsSeek(OsFile *id, off_t offset){
** Make sure all writes to a particular file are committed to disk.
**
** Under Unix, also make sure that the directory entry for the file
-** has been created by fsync-ing the directory that tqcontains the file.
+** has been created by fsync-ing the directory that contains the file.
** If we do not do this and we encounter a power failure, the directory
** entry for the journal might not exist after we reboot. The next
** STQLite to access the file will not know that the journal exists (because
@@ -5,12 +5,12 @@
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
@@ -141,7 +141,7 @@ static unsigned int elapse;
**
** To work around the problem, STQLite has to manage file locks internally
-** on its own. Whenever a new database is opened, we have to tqfind the
+** on its own. Whenever a new database is opened, we have to find the
** specific inode of the database file (the inode is determined by the
** st_dev and st_ino fields of the stat structure that fstat() fills in)
@@ -260,7 +260,7 @@ static Hash lockHash = { STQLITE_HASH_BINARY, 0, 0, 0, 0, 0 };
static Hash openHash = { STQLITE_HASH_BINARY, 0, 0, 0, 0, 0 };
/*
-** Release a lockInfo structure previously allocated by tqfindLockInfo().
+** Release a lockInfo structure previously allocated by findLockInfo().
*/
static void releaseLockInfo(struct lockInfo *pLock){
@@ -271,7 +271,7 @@ static void releaseLockInfo(struct lockInfo *pLock){
}
/*
-** Release a openCnt structure previously allocated by tqfindLockInfo().
+** Release a openCnt structure previously allocated by findLockInfo().
*/
static void releaseOpenCnt(struct openCnt *pOpen){